@@ -5,19 +5,21 @@
     Contact ........ jimmy@advcs.org
     Home Site ...... http://www.advcs.org/
     Program ........ Block Attachments
-    Version ........ 0.5
+    Version ........ 0.6
     Purpose ........ Allows an admin to block any types of attachments
 
 *******************************************************************************/
 
    global $optpage_blocks, $username;
    $admins = array();
-   $file = fopen(SM_PATH . 'config/admins',r);
-   while (!feof($file)){
-      $x = trim(fgets($file));
+   if (!@file_exists(SM_PATH . 'config/admins')) return;
+   $file = @fopen(SM_PATH . 'config/admins',r);
+   while (!@feof($file)){
+      $x = trim(@fgets($file,100));
       if (strlen($x)>0)
          $admins[]= $x;
    }
+   @fclose($file);
 
    $auth = in_array($username, $admins);
    if (!$auth) return;
