@@ -1,11 +1,11 @@
-<?
+<?php
 /*******************************************************************************
 
     Author ......... Jimmy Conner
     Contact ........ jimmy@advcs.org
     Home Site ...... http://www.advcs.org/
     Program ........ Block Attachments
-    Version ........ 0.5
+    Version ........ 0.6
     Purpose ........ Allows an admin to block any types of attachments
 
 *******************************************************************************/
