@@ -5,7 +5,7 @@
     Contact ........ jimmy@advcs.org
     Home Site ...... http://www.advcs.org/
     Program ........ Block Attachments
-    Version ........ 0.5
+    Version ........ 0.6
     Purpose ........ Allows an admin to block any types of attachments
 
 *******************************************************************************/
@@ -21,12 +21,14 @@ require_once(SM_PATH . 'include/load_prefs.php');
 global $username;
 
 $admins = array();
-$file = fopen(SM_PATH . 'config/admins',r);
-while (!feof($file)){
-   $x = trim(fgets($file));
+if (!@file_exists(SM_PATH . 'config/admins')) return;
+$file = @fopen(SM_PATH . 'config/admins',r);
+while (!@feof($file)){
+   $x = trim(@fgets($file,100));
    if (strlen($x)>0)
       $admins[]= $x;
 }
+@fclose($file);
 
 $auth = in_array($username, $admins);
 if (!$auth) return;
